Run notebooks locally
------------------------

1. Ensure the following are installed:

   * `Jupyter Lab <https://jupyter.org/install#jupyterlab>`_
   * `git <https://git-scm.com/downloads>`_
   * `dhlab <installation>`_

2. Clone the `digital_tekstanalyse`_ Github repo (from a terminal or command line):

   .. code-block:: shell

      git clone git@github.com:NationalLibraryOfNorway/digital_tekstanalyse.git

3. Navigate into the cloned repo and start ``jupyter-lab``  from the terminal

   .. code-block:: shell

      cd digital_tekstanalyse
      jupyter-lab

Once ``jupyter lab`` is up and running, just open any ``.ipynb`` notebook file in the left-hand
menu and follow the instructions to execute the code in the cells.


..
   hyperlink refs

.. _dhlab_pypi: https://pypi.org/project/dhlab/
.. _digital_tekstanalyse: https://github.com/NationalLibraryOfNorway/digital_tekstanalyse
.. _homepage: https://www.nb.no/dh-lab/
